<?php
/**
 * Clase SobranteFaltanteBL
 *
 * @package    
 * @subpackage 
 * @author     SobranteFaltanteBL
 * @version    SVN: $Id: SobranteFaltanteBL.class.php,v 1.1 2008/02/08 21:56:44 william.taype Exp $ 
 */
class SobranteFaltanteBL{
    
  /**
  * 
  *
  * @param $o_SobranteFaltanteBean, objeto de tipo SobranteFaltante 
  * @return Boolean
  */
  public function busquedaSobranteFaltante(SobranteFaltanteBean $o_SobranteFaltanteBean){
    
    $o_SobranteFaltanteDP = new SobranteFaltanteDP($o_SobranteFaltanteBean);
    if($o_SobranteFaltanteBean->getIdSofa()){
      return $o_SobranteFaltanteDP->selectByPk();
    }else{
      return $o_SobranteFaltanteDP->select();
    }
    
  }
  
  public function busquedaSobranteFaltanteResulset(SobranteFaltanteBean $o_SobranteFaltanteBean){
    
    $o_SobranteFaltanteDP = new SobranteFaltanteDP($o_SobranteFaltanteBean);
    return $o_SobranteFaltanteDP->selectResultset();
        
  }
  
  public function insertarSobranteFaltante(SobranteFaltanteBean $o_SobranteFaltanteBean){
    
    $o_SobranteFaltanteCT = new SobranteFaltanteCT();
    return $o_SobranteFaltanteCT->guardar($o_SobranteFaltanteBean);
    
  }
  public function modificarSobranteFaltante(SobranteFaltanteBean $o_SobranteFaltanteBean){
      $o_SobranteFaltanteCT = new SobranteFaltanteCT();
      return $o_SobranteFaltanteCT->modificar($o_SobranteFaltanteBean);
  }
  /**
	* Función que retorna un objeto SobranteFaltante o una lista de Objetos de SobranteFaltante,
	* dependiendo del parametro que se le envia si este contiene o no el Id de SobranteFaltante
	*
	* @param $o_SobranteFaltanteBean, es un objeto de tipo SobranteFaltante
	* @return Object
	*/
	public function modificarEstadoSobranteFaltante(SobranteFaltanteBean $o_SobranteFaltanteBean){
	  
	}
  
  public function eliminarSobranteFaltante(SobranteFaltanteBean $o_SobranteFaltanteBean){
    $o_SobranteFaltanteCT = new SobranteFaltanteCT();
    return $o_SobranteFaltanteCT->eliminar($o_SobranteFaltanteBean);
    
  }
  
  public function getCountResult(SobranteFaltanteBean $o_SobranteFaltanteBean){
    $o_SobranteFaltanteCT = new SobranteFaltanteCT();
    return $o_SobranteFaltanteCT->totalRegistros($o_SobranteFaltanteBean);
  }
  
  public function getTotalMonto(SobranteFaltanteBean $o_SobranteFaltanteBean){
    $o_SobranteFaltanteCT = new SobranteFaltanteCT();
    return $o_SobranteFaltanteCT->totalMonto($o_SobranteFaltanteBean);
  }
}

