<?php

class SobranteFaltanteSystemClass {

  private $o_ParamBean;
  
  public function __construct($o_ParamBean){
    $this->o_ParamBean = $o_ParamBean;
  }
  
  private function getObjParamBean(){
    return $this->o_ParamBean;
  }
  
  public function insertSobranteFaltante(){
    
    $o_SobranteFaltanteBL = new SobranteFaltanteBL();
    return $o_SobranteFaltanteBL->insertarSobranteFaltante($this->getObjParamBean());
    
  }
  
  public function insertUsuario($o_UsuarioBean){
    $o_UsuarioBL = new UsuarioBL();
    $o_UsuarioBL->insertarUsuario($o_UsuarioBean);
  }
   
  public function eliminarSobranteFaltante(){
    
    $o_SobranteFaltanteBL = new SobranteFaltanteBL();
    return $o_SobranteFaltanteBL->eliminarSobranteFaltante($this->getObjParamBean());
    
  }
  
  public function actualizarSobranteFaltante(){
    
    $o_SobranteFaltanteBL = new SobranteFaltanteBL();
    return $o_SobranteFaltanteBL->modificarSobranteFaltante($this->getObjParamBean());
    
  }
  
  public function getSobranteFaltante(){
  
    $o_SobranteFaltanteBL = new SobranteFaltanteBL();
    return $o_SobranteFaltanteBL->busquedaSobranteFaltante($this->getObjParamBean());
  
  }
   
  public function getColaborador(){
    $o_ColaboradorBL = new ColaboradorBL();
    return $o_ColaboradorBL->busquedaColaborador($this->getObjParamBean());
    
  }
  public function getGrado(){
    $o_GradoBL = new GradoBL();
    return $o_GradoBL->busquedaGrado(new GradoBean());
    
  }
  /*public function getColaborador(){
    
    $o_ColaboradorBL = new ColaboradorBL();
    return $o_ColaboradorBL->getbusquedaColaborador($this->getObjParamBean());
  }*/
  
  public function getEspecialidad(){
    
    $o_EspecialidadBL = new EspecialidadBL();
    return $o_EspecialidadBL->getEspecialidad($this->getObjParamBean());
  }

}